@@ -53,6 +53,10 @@
 #include <sipwitch/mapped.h>
 #endif
 
+#ifndef	_SIPWITCH_RTPPROXY_H
+#include <sipwitch/rtpproxy.h>
+#endif
+
 NAMESPACE_SIPWITCH
 using namespace UCOMMON_NAMESPACE;
 
@@ -105,25 +109,6 @@ public:
 			{return service::cfg;};
 	};
 
-	class __EXPORT subscriber : public LinkedObject
-	{
-	protected:
-		friend class service;
-
-		static rwlock_t locking;
-		static LinkedObject *list;
-
-		subscriber(const char *p, const char *listen, size_t size);
-		void reopen(const char *listen);
-		void write(char *str);
-		void close(void);
-
-		mutex_t mutex;
-		fsys_t fs;
-		char listen[80];
-		char path[1];
-	};
-
 	class __EXPORT callback : public OrderedObject
     {
 	protected:
@@ -139,13 +124,13 @@ public:
         callback(int level = 0, const char *id = NULL);
         virtual ~callback();
 
-		inline void *alloc(service *cfgp, size_t size)
+		inline static void *alloc(service *cfgp, size_t size)
 			{return cfgp->alloc_locked(size);};
 
-		inline char *dup(service *cfgp, const char *s)
+		inline static char *dup(service *cfgp, const char *s)
 			{return cfgp->dup_locked(s);};
 
-		inline bool isConfigured(void)
+		inline static bool isConfigured(void)
 			{return service::cfg != NULL;};
 
 		inline bool isActive(void)
@@ -158,6 +143,7 @@ public:
 		virtual void start(service *cfg);
 		virtual void stop(service *cfg);
 		virtual bool reload(service *cfg);
+		virtual bool classifier(rtpproxy::session *session, rtpproxy::session *source, struct sockaddr *addr); 
     };
     
 	service(const char *name, size_t s = 0);
@@ -187,9 +173,6 @@ public:
 	static void dump(FILE *fp, keynode *node, unsigned level);
 	static void snapshot(const char *uid);
 	static void dumpfile(const char *uid);
-	static void unsubscribe(const char *path);
-	static void subscribe(const char *path, const char *cmds = NULL);
-	static void publish(const char *path, const char *fmt, ...) __PRINTF(2, 3);
 	static void result(const char *value);
 	static FILE *open(const char *uid = NULL, const char *cfgpath = NULL);
 	static bool state(const char *value);
@@ -198,6 +181,7 @@ public:
 	static void snmptrap(unsigned id, const char *descr);
 	static long uptime(void);
 	static bool match(const char *digits, const char *pattern, bool partial);
+	static keynode *get(void);
 
 	static callback *getComponent(const char *id);
 	static keynode *getProtected(const char *path);
@@ -211,11 +195,15 @@ public:
 	virtual bool confirm(const char *user);
 	bool commit(const char *user);
 
+	static bool classify(rtpproxy::session *session, rtpproxy::session *source, struct sockaddr *addr);
 	static void activate(MappedRegistry *rr);
 	static void expire(MappedRegistry *rr);
 	static bool check(void);
 	static void release(keynode *node);
 
+	static inline bool isProxied(void)
+		{return classify(NULL, NULL, NULL);};
+
 protected:
 	friend class instance;
 
