@@ -367,6 +367,8 @@ void registry::cleanup(time_t period)
 			service::expire(rr);
 			expire(rr);
 		}
+		else if(!rr->inuse && rr->type == MappedRegistry::EXPIRED && !rr->status == MappedRegistry::OFFLINE)
+			service::expire(rr);
 		locking.commit();
 		Thread::yield();
 	}
@@ -485,7 +487,7 @@ registry::mapped *registry::create(const char *id)
 
 	locking.modify();
 	rr = find(id);
-	if(rr && rr->type != MappedRegistry::TEMPORARY) {
+	if(rr && rr->type != MappedRegistry::TEMPORARY && rr->type != MappedRegistry::EXPIRED) {
 		locking.share();
 		return rr;
 	}
@@ -873,7 +875,6 @@ unsigned registry::mapped::setTarget(Socket::address& target_addr, time_t lease,
 	linked_pointer<target> tp;
 	socklen_t len;
 	bool creating = false;
-	char user[65];
 
 	ai = target_addr.getAddr();
 	if(!ai)
@@ -1002,7 +1003,6 @@ bool registry::mapped::expire(Socket::address& saddr)
 	}
 	if(!active_count) {
 		Mutex::protect(this);
-		status = MappedRegistry::OFFLINE;
 		type = MappedRegistry::EXPIRED;
 		expires = 0;
 		Mutex::release(this);
@@ -1052,7 +1052,6 @@ unsigned registry::mapped::addTarget(Socket::address& target_addr, time_t lease,
 	target *expired = NULL;
 	time_t now;
 	socklen_t len;
-	char user[65];
 
 	ai = target_addr.getAddr();
 	if(!ai)
