@@ -354,7 +354,7 @@ private:
 	String agent;
 	String system;
 	String anon;
-	short port;
+	unsigned short port;
 	bool incoming, outgoing, dumping;
 	int send101;
 	timeout_t ring_timer, cfna_timer, reset_timer;
